@@ -227,15 +227,23 @@ def _read_nc(cls, ds):
     # Parse any extra metadata columns
     # Requires 1 filter per item
 
-    # stupid dataframes and their returning of copies
-    from .dataframe import ScmDataFrame
-
-    is_scmdf = isinstance(df, ScmDataFrame)
-    if is_scmdf:
-        df = df.timeseries().reset_index()
+    def _merge_meta(meta, col, value, **filters):
+        result = []
+        for i, r in meta.iterrows():
+            matches = True
+            val = r[col]
+            for k, v in filters.items():
+                if r[k] != v:
+                    matches = False
+                    break
+            if matches:
+                val = value
+            result.append(val)
+        return result
 
     for col in extra_cols:
         var = ds.variables[col]
+        df[col] = None
 
         values = var[:]
         meta_at_coord = np.asarray(
@@ -249,20 +257,12 @@ def _read_nc(cls, ds):
                         var.dimensions, meta_at_coord[(slice(None),) + it.multi_index]
                     )
                 }
-                if is_scmdf:
-                    for c, v in meta_vals.items():
-                        df.loc[df[c] == v, col] = values[it.multi_index]
-
-                else:
-                    df.filter(**meta_vals)[col] = values[it.multi_index]
-
-        if is_scmdf:
-            df.loc[:, col] = df.loc[:, col].astype(values[0].dtype)
-
-    if is_scmdf:
-        df = ScmDataFrame(df)
-    else:
-        df.metadata.update({k: ds.getncattr(k) for k in ds.ncattrs()})
+                df[col] = _merge_meta(df.meta, col, values[it.multi_index], **meta_vals)
+        try:
+            df[col] = df[col].astype(var.dtype)
+        except ValueError:
+            logger.exception("could not convert meta dtype")
+    df.metadata.update({k: ds.getncattr(k) for k in ds.ncattrs()})
 
     return df
 
