@@ -1,5 +1,5 @@
 """
-Plotting helpers for DataFrames
+Plotting helpers for :obj:`ScmRun`
 
 See the example notebook 'plotting-with-seaborn.ipynb' for usage examples
 """
@@ -36,6 +36,9 @@ def lineplot(self, time_axis=None, **kwargs):  # pragma: no cover
     """
     Make a line plot via `seaborn's lineplot <https://seaborn.pydata.org/generated/seaborn.lineplot.html>`_
 
+    If only a single unit is present, it will be used as the y-axis label.
+    The axis object is returned so this can be changed by the user if desired.
+
     Parameters
     ----------
     time_axis : {None, "year", "year-month", "days since 1970-01-01", "seconds since 1970-01-01"}
@@ -66,6 +69,12 @@ def lineplot(self, time_axis=None, **kwargs):  # pragma: no cover
 
     ax = sns.lineplot(data=plt_df, **kwargs)
 
+    try:
+        unit = self.get_unique_meta("unit", no_duplicates=True)
+        ax.set_ylabel(unit)
+    except ValueError:
+        pass  # don't set ylabel
+
     return ax
 
 
@@ -92,7 +101,7 @@ def _deprecated_line_plot(self, **kwargs):  # pragma: no cover
 
 def inject_plotting_methods(cls):
     """
-    Inject the plotting functions
+    Inject the plotting methods
 
     Parameters
     ----------
