@@ -1945,9 +1945,8 @@ def run_append(
 
     Parameters
     ----------
-    runs:
-        The dataframes to append. Values will be attempted to be cast to
-        :class:`ScmRun`.
+    runs: list of :class:`ScmRun`
+        The runs to append. Values will be attempted to be cast to :class:`ScmRun`.
 
     inplace
         If ``True``, then the operation updates the first item in :obj:`runs` and returns
@@ -1976,9 +1975,19 @@ def run_append(
         If :obj:`inplace` is ``True`` but the first element in :obj:`dfs` is not an
         instance of :class:`ScmRun`
 
+        ``runs`` argument is not a list
+
     ValueError
         :obj:`duplicate_msg` option is not recognised.
+
+        No runs are provided to be appended
     """
+    if not isinstance(runs, list):
+        raise TypeError("runs is not a list")
+
+    if not len(runs):
+        raise ValueError("No runs to append")
+
     if inplace:
         if not isinstance(runs[0], ScmRun):
             raise TypeError("Can only append inplace to an ScmRun")
@@ -1988,24 +1997,22 @@ def run_append(
 
     to_join_dfs = []
     to_join_metas = []
-    existing_indices = set(ret._df.columns)
     overlapping_times = False
 
-    def get_unique_idx(idx):
-        if idx not in existing_indices:
-            existing_indices.add(idx)
-            return idx
-
-        new_idx = max(existing_indices) + 1
-        existing_indices.add(new_idx)
-        return new_idx
+    ind = range(ret._df.shape[1])
+    ret._df.columns = ind
+    ret._meta.index = ind
 
+    min_idx = ret._df.shape[1]
     for run in runs[1:]:
         run_to_join_df = run._df
-        ind = [get_unique_idx(i) for i in run_to_join_df.columns]
-        run_to_join_df.columns = ind
 
-        run_to_join_meta = run._meta.to_frame().reset_index(drop=True)
+        max_idx = min_idx + run_to_join_df.shape[1]
+        ind = range(min_idx, max_idx)
+        min_idx = max_idx
+
+        run_to_join_df.columns = ind
+        run_to_join_meta = run._meta.to_frame()
         run_to_join_meta.index = ind
 
         # check everything still makes sense
@@ -2026,9 +2033,7 @@ def run_append(
     ret._time_points = TimePoints(ret._df.index.values)
     ret._df.index = ret._time_points.to_index()
     ret._meta = pd.MultiIndex.from_frame(
-        pd.concat([ret._meta.to_frame().reset_index(drop=True)] + to_join_metas).astype(
-            "category"
-        )
+        pd.concat([ret._meta.to_frame()] + to_join_metas).astype("category")
     )
 
     if ret._duplicated_meta():
@@ -2066,12 +2071,6 @@ def run_append(
     else:
         ret.metadata = _merge_metadata([r.metadata for r in runs])
 
-    # reorder indexes
-    order_idxs = np.argsort(ret._df.columns)
-
-    ret._df = ret._df.iloc[:, order_idxs]
-    ret._meta = ret._meta[order_idxs]
-
     if not inplace:
         return ret
 
