@@ -6,11 +6,13 @@ A large portion of this module was originally from openscm. Thanks to the origin
 
 from datetime import datetime
 
+import cftime
 import numpy as np
 import pandas as pd
 from dateutil import parser
 
 _TARGET_TYPE = np.int64
+_TARGET_DTYPE = "datetime64[s]"
 
 
 class InsufficientDataError(Exception):
@@ -66,20 +68,20 @@ def _format_datetime(dts: np.ndarray) -> np.ndarray:
         If one of the values in :obj:`dts` cannot be converted to :class:`np.datetime64`
     """
     if len(dts) <= 0:  # pylint: disable=len-as-condition
-        return np.array([], dtype="datetime64[s]")
+        return np.array([], dtype=_TARGET_DTYPE)
 
     dtype = dts.dtype.type
     if dts.dtype.kind == "O":
         dtype = np.dtype(type(dts[0])).type
     if issubclass(dtype, np.datetime64):
-        return np.asarray(dts, dtype="datetime64[s]")
+        return np.asarray(dts, dtype=_TARGET_DTYPE)
     if issubclass(dtype, np.floating):
-        return _ufunc_float_year_to_datetime(dts).astype("datetime64[s]")
+        return _ufunc_float_year_to_datetime(dts).astype(_TARGET_DTYPE)
     if issubclass(dtype, np.integer):
-        return (np.asarray(dts) - 1970).astype("datetime64[Y]").astype("datetime64[s]")
+        return (np.asarray(dts) - 1970).astype("datetime64[Y]").astype(_TARGET_DTYPE)
     if issubclass(dtype, str):
-        return _parse_datetime(dts).astype("datetime64[s]")
-    return np.asarray(dts, dtype="datetime64[s]")
+        return _parse_datetime(dts).astype(_TARGET_DTYPE)
+    return np.asarray(dts, dtype=_TARGET_DTYPE)
 
 
 class TimePoints:
@@ -98,6 +100,12 @@ class TimePoints:
         """
         self._values = _format_datetime(np.asarray(values))
 
+    def __len__(self) -> int:
+        """
+        Get the number of time points.
+        """
+        return len(self._values)
+
     @property
     def values(self) -> np.ndarray:
         """
@@ -117,6 +125,18 @@ class TimePoints:
         """
         return pd.Index(self._values.astype(object), dtype=object, name="time")
 
+    def as_cftime(self) -> list:
+        """
+        Get as cftime datetimes
+
+        Returns
+        -------
+        list of cftime.datetime
+        """
+        return [
+            cftime.datetime(*dt.timetuple()[:6]) for dt in self._values.astype(object)
+        ]
+
     def years(self) -> np.ndarray:
         """
         Get year of each time point.
@@ -177,8 +197,9 @@ class TimeseriesConverter:
     """
     Interpolator used to convert data between different time bases
 
-    This is a modified version originally in :mod:`openscm.time.TimeseriesConverter`. The integral preserving interpolation was
-    removed as it is outside the scope of this package.
+    This is a modified version originally in :mod:`openscm.time.TimeseriesConverter`.
+    The integral preserving interpolation was removed as it is outside the scope of
+    this package.
 
     Parameters
     ----------
@@ -205,8 +226,16 @@ class TimeseriesConverter:
         extrapolation_type="linear",
     ):
 
-        self.source = np.array(source_time_points).astype(_TARGET_TYPE, copy=True)
-        self.target = np.array(target_time_points).astype(_TARGET_TYPE, copy=True)
+        self.source = (
+            np.array(source_time_points)
+            .astype(_TARGET_DTYPE)
+            .astype(_TARGET_TYPE, copy=True)
+        )
+        self.target = (
+            np.array(target_time_points)
+            .astype(_TARGET_DTYPE)
+            .astype(_TARGET_TYPE, copy=True)
+        )
         self.interpolation_type = interpolation_type
         self.extrapolation_type = extrapolation_type
 
@@ -233,9 +262,10 @@ class TimeseriesConverter:
         bool
             Can I convert between the time points?
         """
-        if self.extrapolation_type is None:
-            if source[0] > target[0] or source[-1] < target[-1]:
-                return False
+        if self.extrapolation_type is None and (
+            source[0] > target[0] or source[-1] < target[-1]
+        ):
+            return False
 
         return True
 
@@ -262,6 +292,8 @@ class TimeseriesConverter:
         """
         Wrap :func:`_convert_unsafe` to provide proper error handling.
 
+        Any nan values are removed from :obj:`source` before interpolation
+
         Parameters
         ----------
         values
@@ -286,6 +318,13 @@ class TimeseriesConverter:
         np.ndarray
             Converted time period average data for timeseries :obj:`values`
         """
+        values = np.asarray(values)
+        # Check for nans
+        nan_mask = np.isnan(values)
+        if nan_mask.sum():
+            values = values[~nan_mask]
+            source_time_points = source_time_points[~nan_mask]
+
         if len(values) < 3:
             raise InsufficientDataError
 
